%% Extract a common-azimuth section from the first-arrival travel-time
%% matrix 'ttime'.
%%
%%	The section is extracted by starting from a source 'src', drawing a line 
%%	from it in the direction specified by parameter 'azim', and
%%	including in the output all receivers within 'maxdist' from the line.
%%	The output points are sorted by increasing distance in the direction  
%%
%% Parameters:
%%	src - source number for which to extract the section
%%	azim - azimuth in degrees. The section is extracted in both directions
%%		azim and azim + 180 deg, and for the second of them,
%%		negative signs are assigned to the offset values  
%%	maxdist - maximum distance from the line (meters) for receiver included
%%		in the outputs.
%%	only_positive - optional parameter. If given and set equal true, only positive
%%		direction along 'azim' is considered
%% Returns:
%%	tt - travel times 
%%	dist - distances from the source along the projection line (negative for receivers in 
%%		the direction opposite to 'azim')
%%	offset - source-receiver offsets (negative for receivers in 
%%		the direction opposite to 'azim')
%%	rec - array of receiver numbers

function [ tt, dist, offset, rec ] = gather_common_azimuth(src,azim,maxdist,only_positive)

	global survey xi yi ttime offsets xgrid ygrid src_station

	a = azim*pi/180;		% azimuth in radians

	edir = [ cos(a), sin(a) ];	% unit vector in the direction of the line
	eorth = [ sin(a), -cos(a) ];	% unit vector in the orthogonal direction
 
	xy_src = src_station(src,5:6);			% cooordinates of this source
	xy = survey.lst_station(:,4:5) - xy_src;	% coordinates of all stations 
							% relative to source
	
	% find distances along and across the projection line

	for i=1:size(xy,1)
		dist(i) = dot(xy(i,:),edir);		% projections of xy onto projection line
		d(i) = abs(dot(xy(i,:),eorth));		% distances across projection line
	end

	% select receivers closer than maxdist (indices are the output rec)

	rec = find(d < maxdist);

	tt = ttime(src,rec);
	offset = offsets(src,rec);
	dist = dist(rec);

	% change signs of offsets for receivers in the opposite direction

	ind = find(dist < 0.0);

	if ~isempty(ind)
	  	if nargin > 3 && only_positive		% drop negative dist
	
			tt(ind) = [];
			dist(ind) = [];
			offset(ind) = [];
			rec(ind) = [];
		else
			offset(ind) = -offset(ind);
		end
	end

	% sort by increasing dist

	[ dist, ind ] = sort(dist);

	tt = tt(ind);
	offset = offset(ind);
	rec = rec(ind);
end

