global survey xi yi ttime offsets xgrid ygrid src_station

%%% In this script, I have changed figure numbers to correspond to the task numbers
%%% (such as figures 41, 42, etc. for task 4).
%%% In task 4, I've also added plots of crossover distances and maximum offsets
%%% to help guiding interpretation of the common-offset plots in process_coffs.m.
%%% Also corrected an error in the calculation of the source-receiver distance 
%%% in tt_linear_moveout(...). The strange plot of travel times was due to this error.
%%%
%%% --- I.M., March 24 2021
%%% ===============================================================================

%% Load the survey layout (coordinates of sources and receivers).
%% The layout comes in structure 'survey'.  After loading, view
%% its contents by typing 'survey' in Octave console

load layout.mat

%% Structure 'survey' contains several values, of which the important for us is
%% 'survey.lst_srcstations'. Each row of this matrix contains parameters of one
%% 'station' on the ground (a spot marked with pink paint) intended for conducting
%% seismic shots (hammer strikes). The columns of this matrix are:
%% 	1) source line number (assigned during planning the acquisition)
%% 	2) source station number (assigned during planning the acquisition)
%% 	3-4) source station numbers within the rectangular grid of the survey.
%%		These numbers were set during initial processing of the layout;  
%% 	5-6) source station coordinates: (easting, northing) relative to a (0,0) point 
%%		selected during surveying (wooden stake, also used in the resistivity survey)
%%	7) source-station elevation.	


%% load the observer's log (see file 'log.txt')
%% This will be a matrix with columns explained in log.txt:

obs_log = load('log.txt');

%% In obs_log, each row corresponds to one shot (seismic data file, FFID).
%% Columns 3 and 4 are the source line and station numbers that were actually used
%% when conducting the work. We need to extract these records from
%% matrix 'survey.lst_srcstations'. In 'survey.lst_srcstations', the corresponding
%% columns are 1 and 2. Here is how we extract the source stations actually used:

src_station = zeros(rows(obs_log),columns(survey.lst_srcstations));	% allocate

for i=1:rows(src_station)
	ind = find(survey.lst_srcstations(:,1)==obs_log(i,3) & ...
			survey.lst_srcstations(:,2)==obs_log(i,4));

	if ~isempty(ind)
		src_station(i,:) = survey.lst_srcstations(ind(1),:);
	end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% (1)	Plot source and receiver coordinates 
%	for the actually recorded shots.
%
%	Look at this layout carefully.
%
%	As you will see, the 96-channel cable was laid out in 
%	a snaking pattern starting from the SW corner of the area and
%	ending at the NW corner, with 15 channels in one W-E line,
%	with every 16-th phone between the lines.  
%
%	The sources were also arranged in lines running diagonally (SW to NE)
%	relative to the receiver lines. The recording system
%	was connected to the cable between  channels 73 and 74
%	(this is somewhere in the middle of the northern edge of the
%	receiver swath.
%
%	Sources were hammer strikes using a specially designed integrated
%	slide hammer.
%
%	Also note that due to various mistakes by our student crew,
%	(which always happen even with professional crews), some source points
%	were missed and one source line turned out to be too long. 
%	Anyway, in seismic work, we usually want to utilize all recorded shots.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure(1);
clf
hold on

	% Plot different 16-channel geophone lines by pluses '+' of different colors:

line1=1:16; 	% geophone lines to plot
line2=17:32; 	
line3=33:48; 	
line4=49:64;
line5=65:80;
line6=81:96;

plot(survey.lst_station(line1,4),survey.lst_station(line1,5),'r+');
plot(survey.lst_station(line2,4),survey.lst_station(line2,5),'g+');
plot(survey.lst_station(line3,4),survey.lst_station(line3,5),'b+');
plot(survey.lst_station(line4,4),survey.lst_station(line4,5),'r+');
plot(survey.lst_station(line5,4),survey.lst_station(line5,5),'g+');
plot(survey.lst_station(line6,4),survey.lst_station(line6,5),'b+');

	% plot source positions by black asterisks '*'

plot(src_station(:,5),src_station(:,6),'*k');	% sources

xlabel('X');
ylabel('Y');
title('Hammer 3D UofS Geophysics Field School Sept 2019');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% (2)	Create a synthetic refractor surface covering the whole area
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

global	refractor1
 
% create a surface at constant depth h with a pyramid at the center shallowing to 0.5*h

h = 6;		% target depth of refractor

refractor1 = [ 	-21 -11 h; -21 41 h; 61 41 h; 61 -11 h; 
		8 5 h; 8 25 h; 32 25 h; 32 5 h; 
		20 15 0.5*h
	];

% grid this refractor1 on a regular grid and plot it

xgrid = linspace(-20,60,100)';
ygrid = linspace(-10,40,50)';
[xi, yi] = meshgrid(xgrid,ygrid);

depth_map = griddata(refractor1(:,1), refractor1(:,2), refractor1(:,3), xi, yi, 'linear');

figure(2)

imagesc(xgrid,ygrid,depth_map)
colorbar

xlabel('X');
ylabel('Y');

title('Depth of target refractor');


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% (3)	Generate and plot a synthetic refraction travel-time dataset for the
%	source-receiver distribution in figure(1)
%
% (3a)	Prior to making the final plots, fill in the missing code in 
%	functions tt_delay() and tt_linear_moveout(). Test these functions by modeling 
%	(and maybe plotting) their results for locations outside of the uplift
%	in your model (where the refractor is at h = 10 m and the results are predictable.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

V0 = 1.0;	% 1.0;	% overburden velocity
Vrefr = 2.5;	% refractor velocity

	% you can obtain the travel times by using the delay-time formula ('ABC')
	% in several steps:

	% 1-2) model travel times of direct waves and headwaves along the refractor
	% waves from source 'i' to each receiver:

ns = rows(src_station);			% number of sources for brevity
nr = rows(survey.lst_station);		% number of receivers

	% precompute linear-moveout times (times along the refractor)
	% from each source to each receiver
	% in the following matrices, rows correspond to sources and columns to receivers

direct_wave = zeros(ns,nr);
refraction = zeros(ns,nr);

offsets = zeros(ns,nr);		% source-receiver distances
azimuths = zeros(ns,nr);	% source-receiver azimuths
midpoints = zeros(ns,2*nr);	% this matrix will contain source-receiver midpoints (pairs of (x,y))

crossover = zeros(1,ns);	% smallest crossover distances for each source
max_offset = zeros(1,ns);	% maximum source-receiver offset for each source

for i=1:ns

  direct_wave(i,:) = tt_linear_moveout(src_station(i,5:6),survey.lst_station(:,4:5),V0);

  [ t, offs, az, mp ] = tt_linear_moveout(src_station(i,5:6),survey.lst_station(:,4:5),Vrefr);

  refraction(i,:) = transpose(t);	% times and offsets are returned as columns, but we need them as rows
  offsets(i,:) = transpose(offs);
  azimuths(i,:) = transpose(az);

  midpoints(i,((1:nr)*2-1)) = transpose(mp(:,1));	% row of midpoint X (stored in odd-numbered columns)
  midpoints(i,((1:nr)*2)) = transpose(mp(:,2));		% row of midpoint Y (stored in even-numbered columns)
end

	% precompute delay times for each source and receiver

delay_src = tt_delay(src_station(:,5:6),V0,Vrefr);
delay_rec = tt_delay(survey.lst_station(:,4:5),V0,Vrefr);

	% combine these times into total source-receiver times

ttime = refraction;		

for i=1:ns
	max_offset(i) = max(offsets(i,:));	% largest offset for this shot

		% construct headwave time as refractor time plus two delays:

	ttime(i,:) = ttime(i,:) + delay_src(i) + delay_rec(:)';	

		% replace it with direct-wave time where the direct wave arrives earlier
		% (this would be at pre-crossover distances)

	tdir = direct_wave(i,:);	% row of direct-wave times
  
	ind = find(ttime(i,:) > tdir);

	ttime(i,ind) = tdir(ind);

	dwoffs = offsets(i,ind);	% range of direct-wave offsets for this shot

	crossover(i) = max(dwoffs);	% crossover distance estimated as maximum direct-wave distance
end

%ttime		% test printout 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% (4) Examine the resulting travel times and make plots:
%
% (4a)	Make color plots of 'ttime' from 2-3 shots by using 'imagesc' as above, 
%	or by using 'contour'. Comment whether you can see the uplifted refractor at the
%	center of the survey area.
%

plot_tt_shot(41,[20,70,106])

% (4b)	Select the W-E line of receivers called 'line4' above and graph the travel times
%	along this line from: A) two shots located near the western and eastern ends of this line,
%	B) another shot located a little south from the middle of this line. Comment whether
%	you can see expressions of the dome on the refractor.
%
figure(42)
clf

plot(offsets(56,line4),ttime(56,line4),'k',offsets(152,line4),ttime(152,line4),'r',offsets(128,line4),ttime(128,line4),'b')
title('Travel Times Along Line 4');
xlabel('Offset');
ylabel('Time');
legend({'Western Shot','Eastern Shot','Middle Shot'}, 'location', 'southeast');

% (4c)	Plot histograms of source-receiver offsets (using function 'hist()') and 
%	azimuths (using 'rose()') 
%
figure(43)
clf
subplot(1,2,1)
hist(offsets)
title('Offsets');

subplot(1,2,2)
rose(azimuths)
title('Azimuths');

% (4d)	Plot the source-receiver midpoints 
%
figure(44)
clf

plot(midpoints(:,1:240:2),midpoints(:,2:240:2),'b*')
xlabel('X');
ylabel('Y');
title('Midpoints');

% (4e) Plot maps of crossover distances and maximum offsets for sources
%
figure(45)
clf
subplot(1,2,1)

plot_map_src(1:ns,crossover)

xlabel('X');
ylabel('Y');
title(sprintf('Crossover distances for target at %1.1f m',h));
axis('equal')
set(gca,'Ydir','normal')

subplot(1,2,2)

plot_map_src(1:ns,max_offset)

xlabel('X');
ylabel('Y');
title('Largest offsets for shots');
axis('equal')
set(gca,'Ydir','normal')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

save lab4.mat survey src_station nr ns refractor1 xgrid ygrid offsets midpoints ttime 

% using these data, I will try producing the midpoint-sorted travel times later 
% (or you can try it for bonus!). After that, the common-midpoint travel-time curves
% can be inverted for the shape of the refractor

